@@ -1,5 +1,4 @@
 import numpy as np
-import pandas as pd
 from sklearn.metrics import confusion_matrix
 # from .model.EventManager import EventManager
 
@@ -78,8 +77,12 @@ class Scorer:
 
     def getRecords(self):
 
+        return self.recordResult.values()
+        
+    def getRecordsAsDataframe(self):
+        import pandas as pd
         return pd.DataFrame(
-            [self.recordResult[recordName] for recordName in self.recordResult],
+            self.getRecords(),
             index=list(self.recordResult.keys()),
         )
 
